Documentation
¶
Index ¶
- type Config
- type DashboardMeetingParticipantsResponse
- type Meeting
- type MeetingParticipant
- type Member
- type OldPaginate
- type Paginate
- type Service
- func (s *Service) AddGroupMembers(groupID string, toAdd []string) error
- func (s *Service) CachedMeetingAttendees(meetingID string, meetingType string) ([]MeetingParticipant, error)
- func (s *Service) CreateUsers(action string, users []UserToCreate) error
- func (s *Service) CurrentMeetings(nextPage string) ([]Meeting, error)
- func (s *Service) EndMeeting(meetingID string) error
- func (s *Service) GetUsers() ([]User, error)
- func (s *Service) ListGroupMembers(groupID string, pageNum int) ([]Member, error)
- func (s *Service) MeetingAttendees(meetingID string, meetingType string, nextPage string) (participants []MeetingParticipant, err error)
- func (s *Service) PastMeetings() ([]Meeting, error)
- func (s *Service) UpdateUser(uid string, u UpdateUserBody) error
- type UpdateUserBody
- type User
- type UserToCreate
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DashboardMeetingParticipantsResponse ¶ added in v0.0.4
type DashboardMeetingParticipantsResponse struct {
Paginate
Participants []MeetingParticipant `json:"participants"`
}
type Meeting ¶
type Meeting struct {
UUID string `json:"uuid"`
ID int `json:"id"`
Topic string `json:"topic"`
Host string `json:"host"`
Email string `json:"email"`
UserType string `json:"user_type"`
StartTime string `json:"start_time"`
EndTime string `json:"end_time"`
Duration string `json:"duration"`
Participants int `json:"participants"`
HasPstn bool `json:"has_pstn"`
HasVoip bool `json:"has_voip"`
Has3RdPartyAudio bool `json:"has_3rd_party_audio"`
HasVideo bool `json:"has_video"`
HasRecording bool `json:"has_recording"`
HasSip bool `json:"has_sip"`
}
Represents a past meeting in zoom
type MeetingParticipant ¶ added in v0.0.4
type MeetingParticipant struct {
ID string `json:"id"`
UserID string `json:"user_id"`
UserName string `json:"user_name"`
Device string `json:"device"`
IPAddress string `json:"ip_address"`
Location string `json:"location"`
NetworkType string `json:"network_type"`
Microphone string `json:"microphone"`
Speaker string `json:"speaker"`
DataCenter string `json:"data_center"`
ConnectionType string `json:"connection_type"`
JoinTime time.Time `json:"join_time"`
LeaveTime time.Time `json:"leave_time"`
Recording bool `json:"recording"`
PcName string `json:"pc_name"`
Domain string `json:"domain"`
MacAddr string `json:"mac_addr"`
HarddiskID string `json:"harddisk_id"`
Version string `json:"version"`
LeaveReason string `json:"leave_reason"`
}
type OldPaginate ¶
type Paginate ¶
type Paginate struct {
PageCount int `json:"page_count"`
PageSize int `json:"page_size"`
TotalRecords int `json:"total_records"`
NextPageToken string `json:"next_page_token"`
}
Pagination stuff related to many resources
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
All the things needed to interact with Zoom
func NewService ¶
Setup a new service and test the connection
func (*Service) AddGroupMembers ¶
func (*Service) CachedMeetingAttendees ¶ added in v0.0.4
func (s *Service) CachedMeetingAttendees(meetingID string, meetingType string) ([]MeetingParticipant, error)
Get all past meetings form the cache or get fresh
func (*Service) CreateUsers ¶ added in v0.0.4
func (s *Service) CreateUsers(action string, users []UserToCreate) error
func (*Service) CurrentMeetings ¶
func (*Service) EndMeeting ¶
func (*Service) ListGroupMembers ¶
func (*Service) MeetingAttendees ¶ added in v0.0.4
func (*Service) PastMeetings ¶
Get all past meetings form the cache or get fresh
func (*Service) UpdateUser ¶ added in v0.0.4
func (s *Service) UpdateUser(uid string, u UpdateUserBody) error
type UpdateUserBody ¶ added in v0.0.4
type UpdateUserBody struct {
FirstName string `json:"first_name,omitempty"`
LastName string `json:"last_name,omitempty"`
Type string `json:"type,omitempty"`
Pmi string `json:"pmi,omitempty"`
Timezone string `json:"timezone,omitempty"`
Dept string `json:"dept,omitempty"`
VanityName string `json:"vanity_name,omitempty"`
HostKey string `json:"host_key,omitempty"`
CmsUserID string `json:"cms_user_id,omitempty"`
JobTitle string `json:"job_title,omitempty"`
Company string `json:"company,omitempty"`
Location string `json:"location,omitempty"`
PhoneNumber string `json:"phone_number,omitempty"`
PhoneCountry string `json:"phone_country,omitempty"`
}
type User ¶
type User struct {
ID string `json:"id"`
FirstName string `json:"first_name"`
LastName string `json:"last_name"`
Email string `json:"email"`
Type int `json:"type"`
Pmi int `json:"pmi"`
Timezone string `json:"timezone"`
Verified int `json:"verified"`
Dept string `json:"dept"`
CreatedAt time.Time `json:"created_at"`
LastLoginTime string `json:"last_login_time"`
LastClientVersion string `json:"last_client_version"`
PicURL string `json:"pic_url"`
ImGroupIds []string `json:"im_group_ids"`
Status string `json:"status"`
}
Click to show internal directories.
Click to hide internal directories.